@@ -1,9 +1,7 @@
 #' Extract statistics from Fitted Models
 #'
-#' This function extracts and calculates various results for fitted models such
-#' as BLUEs, BLUPs, unit errors and heritabilities. Note that most results can
-#' only be calculated if a model is fitted with genotype as fixed or random.
-#' This is indicated in the list below with "F" and "R"
+#' This function is deprecated. Use \code{\link{extractSTA}} for extracting
+#' results from fitted models.
 #'
 #' Possible options for \code{what} are:
 #' \describe{
@@ -74,20 +72,6 @@
 #'
 #' @seealso \code{\link{fitTD}}
 #'
-#' @examples
-#' ## Fit model using SpATS.
-#' myModel <- fitTD(TD = TDHeat05, design = "res.rowcol", traits = "yield")
-#'
-#' ## Extract all available statistics from the fitted model.
-#' extr <- extract(myModel)
-#'
-#' ## Extract only the BLUEs from the fitted model.
-#' BLUEs <- extract(myModel, what = "BLUEs")
-#'
-#' ## Extract only the BLUEs from the fitted model and keep trial as variable in
-#' ## the output.
-#' BLUEs2 <- extract(myModel, what = "BLUEs", keep = "trial")
-#'
 #' @importFrom utils capture.output
 #' @export
 extract <- function(STA,
@@ -96,6 +80,7 @@ extract <- function(STA,
                     what = "all",
                     keep = NULL,
                     restoreColNames = FALSE) {
+  .Deprecated("extractSTA")
   ## Checks.
   if (missing(STA) || !inherits(STA, "STA")) {
     stop("STA has to be an object of class STA.\n")
@@ -623,7 +608,8 @@ extractAsreml <- function(STA,
   result <- setNames(vector(mode = "list", length = length(what)), what)
   ## Construct assocForm for use in associate in predict.
   if (length(grep(pattern = "+ checkId +", x = getCall(mf[[1]]))) > 0) {
-    assocForm <- formula("~ checkId:genotype")
+    #assocForm <- formula("~ checkId:genotype")
+    assocForm <- formula("~ NULL")
   } else {
     assocForm <- formula("~ NULL")
   }
@@ -883,7 +869,7 @@ extractAsreml <- function(STA,
       }
     })
   }
-  ## Compute lsd with signifcance level 5%.
+  ## Compute lsd with significance level 5%.
   ## asreml3 saves the predictions inside the asreml object.
   ## asreml4 creates a list containing nothing but the predictions.
   if ("lsd" %in% what) {
